gofigr package
==============

Module contents
---------------

.. automodule:: gofigr
   :members:
   :undoc-members:
   :show-inheritance:


Submodules
----------

gofigr.jupyter module
---------------------

.. automodule:: gofigr.jupyter
   :members:
   :undoc-members:
   :show-inheritance:

gofigr.models module
--------------------

.. automodule:: gofigr.models
   :members:
   :undoc-members:
   :show-inheritance:

gofigr.watermarks module
------------------------

.. automodule:: gofigr.watermarks
   :members:
   :undoc-members:
   :show-inheritance:

gofigr.annotators module
------------------------

.. automodule:: gofigr.annotators
   :members:
   :undoc-members:
   :show-inheritance:

gofigr.widget module
------------------------

.. automodule:: gofigr.widget
   :members:
   :undoc-members:
   :show-inheritance:


gofigr.backends module
------------------------

.. automodule:: gofigr.backends
   :members:
   :undoc-members:
   :show-inheritance:

gofigr.backends.matplotlib module
----------------------------------

.. automodule:: gofigr.backends.matplotlib
   :members:
   :undoc-members:
   :show-inheritance:

gofigr.backends.plotly module
---------------------------------

.. automodule:: gofigr.backends.plotly
   :members:
   :undoc-members:
   :show-inheritance:

gofigr.backends.plotnine module
---------------------------------

.. automodule:: gofigr.backends.plotnine
   :members:
   :undoc-members:
   :show-inheritance:

gofigr.backends.py3dmol module
-------------------------------

.. automodule:: gofigr.backends.py3dmol
   :members:
   :undoc-members:
   :show-inheritance:
